# Generated by Django 5.0.10 on 2025-02-04 17:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("baseapp_chats", "0009_remove_message_create_message_status_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="message",
            name="deleted",
            field=models.BooleanField(default=False),
        ),
    ]
